(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     20388,        496]
NotebookOptionsPosition[     20817,        487]
NotebookOutlinePosition[     21282,        507]
CellTagsIndexPosition[     21239,        504]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Friction on a slope \n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2018-11-3",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "The module below shows how the friction changes on a slope. \nWhen a block \
is statistically placed on a slope with inclined angle \[Theta] and \
coefficient of friction \[Mu], the friction provided by the slope is a static \
frictional force; as \[Theta] increases gradually and exceeds the critical \
value, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "0"], TraditionalForm]]],
 " = Arctan(\[Mu]), the statistic balance is broken and the block begins to \
move, with the static frictional force changed to kinetic frictional force. \
While in the original balance state, changing the mass of the block, ",
 StyleBox["m",
  FontSlant->"Italic"],
 ", cannot break the balance. \nModule below shows these ideas where \[Mu] \
and ",
 StyleBox["m",
  FontSlant->"Italic"],
 " are variable and \[Theta] can be increased automatically to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Theta]", "0"], TraditionalForm]]],
 ". Play with these parameters to see how the FBD and balance change. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`an$$ = 0, $CellContext`fbd$$ = 
    0, $CellContext`m$$ = 3, $CellContext`\[Mu]$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Mu]$$], 1, 
       Text[
        Style["\[Mu]", Bold, 12]]}, 0, 1.5, 0.01}, {{
       Hold[$CellContext`m$$], 3, 
       Text[
        Style[
        "\!\(\*\nStyleBox[\"m\",\nFontSlant->\"Italic\"]\)", Bold, 12]]}, 1, 
      10, 0.1}, {{
       Hold[$CellContext`an$$], 0, 
       Spacer[0]}, 0, 
      Dynamic[
       ArcTan[$CellContext`\[Mu]$$]], 
      Dynamic[Dynamic[
         ArcTan[$CellContext`\[Mu]$$]]/25]}, {{
       Hold[$CellContext`fbd$$], 0, 
       Spacer[0]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          Row[{
            Text[
             Style["Increase \[Theta]", Bold, 12]], 
            Spacer[40], 
            Text[
             Style[
              Dynamic[
               $CellContext`rnd[($CellContext`an$$/Pi) 180]], Bold, 12]]}]}, {
          Manipulate`Place[3]}, {
          Text[
           Style["Show FBD", Bold, 12]]}, {
          Manipulate`Place[4]}, {
          PaneSelector[{1 -> Grid[{{
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"mg\",\nFontSlant->\"Italic\"]\)", Bold, 
                  12]], 
                Text[
                 Style[
                  Dynamic[
                   $CellContext`rnd[$CellContext`m$$ $CellContext`g]], Bold, 
                  12]]}, {
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"mgsin\",\nFontSlant->\"Italic\"]\)\
\[Theta]", Bold, 12]], 
                Text[
                 Style[
                  Dynamic[
                   $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Sin[$CellContext`an$$]]], Bold, 12]]}, {
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"mgcos\",\nFontSlant->\"Italic\"]\)\
\[Theta]", Bold, 12]], 
                Text[
                 Style[
                  Dynamic[
                   $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Cos[$CellContext`an$$]]], Bold, 12]]}, {
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"f\",\nFontSlant->\"Italic\"]\)", Bold, 
                  12]], 
                Text[
                 Style[
                  Dynamic[
                   If[$CellContext`an$$ < ArcTan[$CellContext`\[Mu]$$], 
                    $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Sin[$CellContext`an$$]], 
                    $CellContext`rnd[(($CellContext`\[Mu]$$ $CellContext`m$$) \
$CellContext`g) Cos[$CellContext`an$$]]]], Bold, 12]]}, {
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"N\",\nFontSlant->\"Italic\"]\)", Bold, 
                  12]], 
                Text[
                 Style[
                  Dynamic[
                   $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Cos[$CellContext`an$$]]], Bold, 12]]}, {
                Text[
                 Style[
                  Subscript["\[Theta]", "0"], Bold, 12]], 
                Text[
                 Style[
                  Dynamic[
                   $CellContext`rnd[
                    N[ArcTan[$CellContext`\[Mu]$$]/Degree]]], Bold, 12]]}, {
                Dynamic[
                 If[$CellContext`an$$ < ArcTan[$CellContext`\[Mu]$$], 
                  Text[
                   Style["Balanced", Bold, 12, 
                    Darker[Green]]], 
                  Text[
                   Style["Unbalanced", Bold, 12, Red]]]]}}, Alignment -> 
              Left]}, 
           Dynamic[$CellContext`fbd$$]]}}, Alignment -> Left, 
        Spacings -> {1, 1}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {600., {296., 304.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`\[Mu]$1537$$ = 0, $CellContext`m$1538$$ = 
    0, $CellContext`an$1539$$ = 0, $CellContext`fbd$1540$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`an$$ = 0, $CellContext`fbd$$ = 
        0, $CellContext`m$$ = 3, $CellContext`\[Mu]$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Mu]$$, $CellContext`\[Mu]$1537$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$1538$$, 0], 
        Hold[$CellContext`an$$, $CellContext`an$1539$$, 0], 
        Hold[$CellContext`fbd$$, $CellContext`fbd$1540$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`l$, $CellContext`h$, $CellContext`s$, \
$CellContext`f$, $CellContext`frc$, $CellContext`\[Theta]$, $CellContext`\
\[Beta]$, $CellContext`a$, $CellContext`movtime$, $CellContext`init$, \
$CellContext`masscolor$, $CellContext`center$, $CellContext`dwf1$, \
$CellContext`dwf2$, $CellContext`dwf3$}, $CellContext`l$ = 
         10; $CellContext`init$ = 
         2/3; $CellContext`\[Theta]$ = $CellContext`an$$; $CellContext`h$ = 
         0.8 (1 + ($CellContext`m$$ - $CellContext`m0)/($CellContext`m2 - \
$CellContext`m1)); $CellContext`s$ = 
         0.5 (1 + ($CellContext`m$$ - $CellContext`m0)/($CellContext`m2 - \
$CellContext`m1)); $CellContext`f$ = 
         2 (1 + ($CellContext`m$$ - $CellContext`m0)/($CellContext`m2 - \
$CellContext`m1)); $CellContext`\[Beta]$ = 
         ArcTan[$CellContext`\[Mu]$$]; $CellContext`center$ = \
($CellContext`init$ $CellContext`l$) {
             Cos[$CellContext`\[Theta]$], 
             Sin[$CellContext`\[Theta]$]} + ($CellContext`h$/2) {
             Cos[$CellContext`\[Theta]$ + Pi/2], 
             Sin[$CellContext`\[Theta]$ + Pi/2]}; $CellContext`frc$ = 
         If[$CellContext`\[Theta]$ < $CellContext`\[Beta]$, $CellContext`f$ 
           Sin[$CellContext`\[Theta]$], ($CellContext`\[Mu]$$ $CellContext`f$)
             Cos[$CellContext`\[Theta]$]]; $CellContext`a$ = 
         1/$CellContext`m$$; $CellContext`movtime$ = 
         If[$CellContext`\[Theta]$ < $CellContext`\[Beta]$, 0, 
           Dynamic[
            Clock[{0, 4, 0.05}, 10]]]; $CellContext`dwf1$ = {
           Thickness[0.003], 
           Line[{{0, 0}, {$CellContext`l$, 0}}], 
           Map[Line[{{#, 0}, {#, 0} - 0.5 {
                Cos[45 Degree], 
                Sin[45 Degree]}}]& , 
            
            Table[$CellContext`i, {$CellContext`i, 0.5, $CellContext`l$, 
              0.5}]], 
           Rotate[{
             Thickness[0.003], 
             Line[{{0, 0}, {$CellContext`l$, 0}}]}, $CellContext`\[Theta]$, {
            0, 0}], 
           Circle[{0, 0}, 1.5, {0, $CellContext`\[Theta]$}], 
           If[$CellContext`\[Theta]$ != 0, 
            Text[
             Style["\[Theta]"], 1.8 {
               Cos[$CellContext`\[Theta]$/2], 
               Sin[$CellContext`\[Theta]$/2]}]]}; $CellContext`masscolor$ = 
         If[$CellContext`\[Theta]$ < $CellContext`\[Beta]$, Green, 
           Red]; $CellContext`dwf2$ = Translate[{
            EdgeForm[{
              Thickness[0.003], Black}], 
            Opacity[0.2], 
            FaceForm[$CellContext`masscolor$], 
            Rotate[
             
             Rectangle[{$CellContext`init$ $CellContext`l$ - $CellContext`s$, 
               0}, {$CellContext`init$ $CellContext`l$ + $CellContext`s$, \
$CellContext`h$}], $CellContext`\[Theta]$, {0, 
             0}]}, (((1/2) $CellContext`a$) $CellContext`movtime$^2) {
             Cos[Pi + $CellContext`\[Theta]$], 
             Sin[Pi + $CellContext`\[Theta]$]}]; $CellContext`dwf3$ = 
         Translate[{
            Opacity[
             Boole[$CellContext`fbd$$ == 1]], 
            Point[$CellContext`center$], 
            Thickness[0.003], 
            Darker[Red], 
            Arrowheads[0.03], 
            
            Arrow[{$CellContext`center$, $CellContext`center$ + \
$CellContext`f$ {0, -1}}], 
            
            Arrow[{$CellContext`center$, $CellContext`center$ + \
($CellContext`f$ Cos[$CellContext`\[Theta]$]) {
                 Cos[$CellContext`\[Theta]$ - Pi/2], 
                 Sin[$CellContext`\[Theta]$ - Pi/2]}}], 
            
            Arrow[{$CellContext`center$, $CellContext`center$ + \
($CellContext`f$ Sin[$CellContext`\[Theta]$]) {
                 Cos[$CellContext`\[Theta]$ + Pi], 
                 Sin[$CellContext`\[Theta]$ + Pi]}}], Dashed, 
            
            Line[{$CellContext`center$ + ($CellContext`f$ 
                Cos[$CellContext`\[Theta]$]) {
                 Cos[$CellContext`\[Theta]$ - Pi/2], 
                 
                 Sin[$CellContext`\[Theta]$ - Pi/
                  2]}, $CellContext`center$ + $CellContext`f$ {0, -1}}], 
            
            Line[{$CellContext`center$ + ($CellContext`f$ 
                Sin[$CellContext`\[Theta]$]) {
                 Cos[$CellContext`\[Theta]$ + Pi], 
                 
                 Sin[$CellContext`\[Theta]$ + 
                  Pi]}, $CellContext`center$ + $CellContext`f$ {0, -1}}], 
            Dashing[{}], 
            
            Circle[$CellContext`center$, $CellContext`f$ 0.25, {
             3 (Pi/2), 3 (Pi/2) + $CellContext`\[Theta]$}], 
            If[$CellContext`\[Theta]$ != 0, {
              Text[
               Style[
               "\[Theta]", 10], $CellContext`center$ + (0.35 $CellContext`f$) {
                  Cos[(3/2) Pi + $CellContext`\[Theta]$/2], 
                  Sin[(3/2) Pi + $CellContext`\[Theta]$/2]}], 
              Translate[
               Rotate[
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"mgsin\",\nFontSlant->\"Italic\"]\)\
\[Theta]", Bold, 
                  12], $CellContext`center$ + ($CellContext`f$ 
                   Sin[$CellContext`\[Theta]$]) {
                    Cos[$CellContext`\[Theta]$ + Pi], 
                    
                    Sin[$CellContext`\[Theta]$ + 
                    Pi]}], $CellContext`\[Theta]$], 0.75 {
                 Cos[$CellContext`\[Theta]$ + Pi], 
                 Sin[$CellContext`\[Theta]$ + Pi]}], 
              Translate[
               Rotate[
                Text[
                 Style[
                 "\!\(\*\nStyleBox[\"mgcos\",\nFontSlant->\"Italic\"]\)\
\[Theta]", Bold, 
                  12], $CellContext`center$ + (((3/4) $CellContext`f$) 
                   Cos[$CellContext`\[Theta]$]) {
                    Cos[$CellContext`\[Theta]$ + (3/2) Pi], 
                    
                    Sin[$CellContext`\[Theta]$ + (3/2) 
                    Pi]}], $CellContext`\[Theta]$ - Pi/2], 0.4 {
                 Cos[$CellContext`\[Theta]$], 
                 Sin[$CellContext`\[Theta]$]}]}], 
            Text[
             Style[
             "\!\(\*\nStyleBox[\"mg\",\nFontSlant->\"Italic\"]\)", Bold, 
              12], $CellContext`center$ + $CellContext`f$ {0, -1.1}], 
            Dashing[{}], 
            Darker[Blue], 
            
            Arrow[{$CellContext`center$, $CellContext`center$ + \
($CellContext`f$ Cos[$CellContext`\[Theta]$]) {
                 Cos[$CellContext`\[Theta]$ + Pi/2], 
                 Sin[$CellContext`\[Theta]$ + Pi/2]}}], 
            
            Arrow[{$CellContext`center$, $CellContext`center$ + \
$CellContext`frc$ {
                 Cos[$CellContext`\[Theta]$], 
                 Sin[$CellContext`\[Theta]$]}}], 
            Text[
             Style[
             "\!\(\*\nStyleBox[\"N\",\nFontSlant->\"Italic\"]\)", Bold, 
              12], $CellContext`center$ + ((1.1 $CellContext`f$) 
               Cos[$CellContext`\[Theta]$]) {
                Cos[$CellContext`\[Theta]$ + Pi/2], 
                Sin[$CellContext`\[Theta]$ + Pi/2]}], 
            If[
             And[$CellContext`\[Theta]$ != 0, $CellContext`\[Mu]$$ != 0], 
             Text[
              Style[
              "\!\(\*\nStyleBox[\"f\",\nFontSlant->\"Italic\"]\)", Bold, 
               12], $CellContext`center$ + (1.15 $CellContext`frc$) {
                 Cos[$CellContext`\[Theta]$], 
                 Sin[$CellContext`\[Theta]$]} + 0.05 {
                 Cos[$CellContext`\[Theta]$ + (3/2) Pi], 
                 Sin[$CellContext`\[Theta]$ + (3/2) Pi]}]]}, (((1/
              2) $CellContext`a$) $CellContext`movtime$^2) {
             Cos[Pi + $CellContext`\[Theta]$], 
             Sin[Pi + $CellContext`\[Theta]$]}]; 
        Graphics[{$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$},
           PlotRange -> {{-1, $CellContext`l$}, {-2, $CellContext`l$}}, 
          ImageSize -> {400, 400}]], 
      "Specifications" :> {{{$CellContext`\[Mu]$$, 1, 
          Text[
           Style["\[Mu]", Bold, 12]]}, 0, 1.5, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 1}, {{$CellContext`m$$, 3, 
          Text[
           Style[
           "\!\(\*\nStyleBox[\"m\",\nFontSlant->\"Italic\"]\)", Bold, 12]]}, 
         1, 10, 0.1, Appearance -> "Labeled", ImageSize -> Tiny, 
         ControlPlacement -> 2}, {{$CellContext`an$$, 0, 
          Spacer[0]}, 0, 
         Dynamic[
          ArcTan[$CellContext`\[Mu]$$]], 
         Dynamic[Dynamic[
            ArcTan[$CellContext`\[Mu]$$]]/25], ImageSize -> Tiny, ControlType -> 
         Trigger, AppearanceElements -> {"PlayPauseButton", "ResetButton"}, 
         ControlPlacement -> 3}, {{$CellContext`fbd$$, 0, 
          Spacer[0]}, {1 -> "On", 0 -> "Off"}, ControlType -> RadioButton, 
         ControlPlacement -> 4}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           Row[{
             Text[
              Style["Increase \[Theta]", Bold, 12]], 
             Spacer[40], 
             Text[
              Style[
               Dynamic[
                $CellContext`rnd[($CellContext`an$$/Pi) 180]], Bold, 12]]}]}, {
           Manipulate`Place[3]}, {
           Text[
            Style["Show FBD", Bold, 12]]}, {
           Manipulate`Place[4]}, {
           PaneSelector[{1 -> Grid[{{
                 Text[
                  Style[
                  "\!\(\*\nStyleBox[\"mg\",\nFontSlant->\"Italic\"]\)", Bold, 
                   12]], 
                 Text[
                  Style[
                   Dynamic[
                    $CellContext`rnd[$CellContext`m$$ $CellContext`g]], Bold, 
                   12]]}, {
                 Text[
                  Style[
                  "\!\(\*\nStyleBox[\"mgsin\",\nFontSlant->\"Italic\"]\)\
\[Theta]", Bold, 12]], 
                 Text[
                  Style[
                   Dynamic[
                    $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Sin[$CellContext`an$$]]], Bold, 12]]}, {
                 Text[
                  Style[
                  "\!\(\*\nStyleBox[\"mgcos\",\nFontSlant->\"Italic\"]\)\
\[Theta]", Bold, 12]], 
                 Text[
                  Style[
                   Dynamic[
                    $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Cos[$CellContext`an$$]]], Bold, 12]]}, {
                 Text[
                  Style[
                  "\!\(\*\nStyleBox[\"f\",\nFontSlant->\"Italic\"]\)", Bold, 
                   12]], 
                 Text[
                  Style[
                   Dynamic[
                    If[$CellContext`an$$ < ArcTan[$CellContext`\[Mu]$$], 
                    $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Sin[$CellContext`an$$]], 
                    $CellContext`rnd[(($CellContext`\[Mu]$$ $CellContext`m$$) \
$CellContext`g) Cos[$CellContext`an$$]]]], Bold, 12]]}, {
                 Text[
                  Style[
                  "\!\(\*\nStyleBox[\"N\",\nFontSlant->\"Italic\"]\)", Bold, 
                   12]], 
                 Text[
                  Style[
                   Dynamic[
                    $CellContext`rnd[($CellContext`m$$ $CellContext`g) 
                    Cos[$CellContext`an$$]]], Bold, 12]]}, {
                 Text[
                  Style[
                   Subscript["\[Theta]", "0"], Bold, 12]], 
                 Text[
                  Style[
                   Dynamic[
                    $CellContext`rnd[
                    N[ArcTan[$CellContext`\[Mu]$$]/Degree]]], Bold, 12]]}, {
                 Dynamic[
                  If[$CellContext`an$$ < ArcTan[$CellContext`\[Mu]$$], 
                   Text[
                    Style["Balanced", Bold, 12, 
                    Darker[Green]]], 
                   Text[
                    Style["Unbalanced", Bold, 12, Red]]]]}}, Alignment -> 
               Left]}, 
            Dynamic[$CellContext`fbd$$]]}}, Alignment -> Left, 
         Spacings -> {1, 1}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{899., {341., 350.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`m1 = 1, $CellContext`m2 = 
       10, $CellContext`m0 = 3, $CellContext`txt[
         Pattern[$CellContext`x, 
          Blank[]]] := Text[
         Style[$CellContext`x, Bold, 12]], $CellContext`rnd[
         Pattern[$CellContext`x, 
          Blank[]]] := Round[$CellContext`x, 0.1], $CellContext`g = 9.8}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 247, 8, 230, "Title"],
Cell[1736, 45, 1031, 23, 159, "Text"],
Cell[2770, 70, 18031, 414, 715, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Mxp7AfBaYwExEC1#wAq4LI4I *)
